==========
SPyderSQL
==========

|MIT|

.. |MIT| image:: https://img.shields.io/pypi/l/SPyderSQL.svg?style=flat-square
    :target: https://opensource.org/licenses/MIT
    :alt: MIT License

**SPyderSQL** is a modern ORM framework for SQL database in Python.

Make your databases faster and powerful!

Features
========

- Modularity and reusability
- Basic SQL functionality provided
- Working with SQLite
- Methods and functions are provided with detailed comments
- Embedding Flexible Data Types for SQLite


Code of Conduct
---------------

Above all, SPyderSQL places great emphasis on polite, thoughtful, and
constructive communication between users and developers.

License
-------

SPyderSQL is distributed under the `MIT license
<https://www.opensource.org/licenses/mit-license.php>`_.